# -*- coding: utf-8 -*-
# Copyright (C) 2023 mhertz <yourname@example.com>
#
# Basic plugin template created by the Deluge Team.
#
# This file is part of dlimit and is licensed under GNU GPL 3.0, or later,
# with the additional special exception to link portions of this program with
# the OpenSSL library. See LICENSE for more details.
from __future__ import unicode_literals

import logging

import deluge.configmanager
from deluge.core.rpcserver import export
from deluge.plugins.pluginbase import CorePluginBase
import deluge.component as component
from twisted.internet.reactor import callLater

log = logging.getLogger(__name__)

DEFAULT_PREFS = {
    'limit': 50.0
}


class Core(CorePluginBase):
    def enable(self):
        self.config = deluge.configmanager.ConfigManager(
            'dlimit.conf', DEFAULT_PREFS)
        self.config.save()
        component.get("EventManager").register_event_handler("SessionStartedEvent", self.z)
        component.get("EventManager").register_event_handler("TorrentAddedEvent", self.z)
        component.get("EventManager").register_event_handler("TorrentFinishedEvent", self.z)
        component.get("EventManager").register_event_handler("TorrentRemovedEvent", self.z)

    def z(self, *args):
        if len(args) == 2 and args[1]:
            return
        callLater(1, self.f)

    def f(self):
        torrentmanager = component.get("TorrentManager")
        torrent_ids = torrentmanager.get_torrent_list()
        count=0
        ids=[]
        for i in torrent_ids:
            t = torrentmanager.torrents.get(i, None)
            a = t.get_status(['state'])['state'].find("Downloading") != -1
            if a:
                count+=1 
                ids.append(i)
        if len(ids) == 1:
            for i in ids:
                t = torrentmanager.torrents.get(i, None)
                a = t.get_status(['max_download_speed'])['max_download_speed']
                if a == -1:
                    return
                t.set_max_download_speed(-1)
                return
        for i in ids:
            t = torrentmanager.torrents.get(i, None)
            a = t.get_status(['max_download_speed'])['max_download_speed']
            if a == self.config['limit']//count:
                return
            t.set_max_download_speed(self.config['limit']*1024//count)

    def disable(self):
        component.get("EventManager").deregister_event_handler("SessionStartedEvent", self.z)
        component.get("EventManager").deregister_event_handler("TorrentAddedEvent", self.z)
        component.get("EventManager").deregister_event_handler("TorrentFinishedEvent", self.z)
        component.get("EventManager").deregister_event_handler("TorrentRemovedEvent", self.z)
        if self.z.active():
            self.z.cancel()

    def update(self):
        pass


    @export
    def set_config(self, config):
        """Sets the config dictionary"""
        for key in config:
            if self.config[key] != config[key]:
                self.config[key] = config[key]
                self.config.save()
                self.z()

    @export
    def get_config(self):
        """Returns the config dictionary"""
        return self.config.config
