/**
 * Script: dlimit.js
 *     The client-side javascript code for the dlimit plugin.
 *
 * Copyright:
 *     (C) mhertz 2022 <yourname@example.com>
 *
 *     This file is part of dlimit and is licensed under GNU GPL 3.0, or
 *     later, with the additional special exception to link portions of this
 *     program with the OpenSSL library. See LICENSE for more details.
 */

dlimitPanel = Ext.extend(Ext.form.FormPanel, {
    constructor: function(config) {
        config = Ext.apply({
            border: false,
            title: _("dlimit"),
            autoHeight: true,
        }, config);
        dlimitPanel.superclass.constructor.call(this, config);
    },
    initComponent: function() {
        dlimitPanel.superclass.initComponent.call(this);
        this.opts = new Deluge.OptionsManager();

        var fieldset = this.add({
            xtype: 'fieldset',
            title: _('dlimit settings'),
            autoHeight: true,
            autoWidth: true,
            defaultType: 'textfield'
        });
        this.opts.bind('limit', fieldset.add({
			fieldLabel: _('Limit (MiB)'),
            anchor:'100%',
            name: 'limit',
            autoWidth: true,
            value: ''
        }));

        deluge.preferences.on('show', this.onPreferencesShow, this);
    },

    onPreferencesShow: function () {
        deluge.client.dlimit.get_config({
            success: function (config) {
            if (!Ext.isEmpty(config['limit'])) {
                config['limit'] = config['limit'];
            }
           
            //Ext.getCmp("mycheck").checked;
            this.opts.set(config);
            },
            scope: this,
        });
    },
    onApply: function(e) {
        var changed = this.opts.getDirty();
        if (!Ext.isObjectEmpty(changed)) {
            if (!Ext.isEmpty(changed['limit'])) {
            changed['limit'] = changed['limit'];
            }
           
            deluge.client.dlimit.set_config(changed, {
                success: this.onSetConfig,
                scope: this,
            });
        }
    },
    onSetConfig: function() {
        this.opts.commit();
    },
});


dlimitPlugin = Ext.extend(Deluge.Plugin, {
    name: "dlimit",

    onDisable: function() {
        deluge.preferences.removePage(this.prefsPage);
    },

    onEnable: function() {
        this.prefsPage = new dlimitPanel();
        this.prefsPage = deluge.preferences.addPage(this.prefsPage);
    }
});

Deluge.registerPlugin('dlimit', dlimitPlugin);

